@@ -123,11 +123,9 @@ class MegamanicEditable:
     security.declarePrivate('at_post_create_script')
     def at_post_create_script(self):
         parent = self.getParentNode()
-        if parent.isMegamanicEditableTemplateObject() and \
-                parent.getAllowAnonymousAdd():
-            self.plone_utils.addPortalMessage('Remember to publish this object (make viewable) %s as well' % self.getId())
-#        import pdb
-#        pdb.set_trace()
+        #if self.isMegamanicEditableTemplateObject() and \
+        #        self.getAllowAnonymousAdd():
+        #    self.plone_utils.addPortalMessage('Remember to publish this object (make viewable) %s as well' % self.getId())
         # A class inheriting from MegamanicEdit must always have a MegamanicEdit
         # class as the first superclass
         for base in self.__class__.__bases__[1:]:
